Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1270)

Unified Diff: chrome/browser/ui/views/location_bar/location_bar_view.h

Issue 2555063003: Render extension URLs with chips (Closed)
Patch Set: Chip -> text Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/location_bar/location_bar_view.h
diff --git a/chrome/browser/ui/views/location_bar/location_bar_view.h b/chrome/browser/ui/views/location_bar/location_bar_view.h
index 44248e059e0086a4d61421f5942cc447036a9605..599d2c3501596cb4fefc026aa9eb261ac7e19303 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_view.h
+++ b/chrome/browser/ui/views/location_bar/location_bar_view.h
@@ -311,18 +311,21 @@ class LocationBarView : public LocationBar,
// Helper to show the first run info bubble.
void ShowFirstRunBubbleInternal();
- // Returns text describing the URL's security level, to be placed in the
- // security chip.
- base::string16 GetSecurityText() const;
+ // Returns text to be placed in the location icon view.
+ // - For secure/insecure pages, returns text describing the URL's security
+ // level.
+ // - For extension URLs, returns the extension name.
+ base::string16 GetLocationIconText() const;
bool ShouldShowKeywordBubble() const;
- // Returns true when the current page is explicitly secure or insecure.
- // In these cases, we should show the state of the security chip.
- bool ShouldShowSecurityChip() const;
+ // Returns true if any of the following is true:
+ // - the current page is explicitly secure or insecure.
+ // - the current page URL is a chrome-extension:// URL.
+ bool ShouldShowLocationIconText() const;
- // Returns true if the chip should be animated
- bool ShouldAnimateSecurityChip() const;
+ // Returns true if the location icon text should be animated.
+ bool ShouldAnimateLocationIconTextVisibilityChange() const;
// Used to "reverse" the URL showing/hiding animations, since we use separate
// animations whose curves are not true inverses of each other. Based on the
« no previous file with comments | « chrome/browser/ui/location_bar/location_bar.cc ('k') | chrome/browser/ui/views/location_bar/location_bar_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698